@@ -279,9 +279,9 @@ resolved.ClusterFuture <- function(x, run = TRUE, timeout = NULL, ...) {
 
     isValid <- isConnectionValid(con)
     if (!isValid) {
-      label <- x$label
-      if (is.null(label)) label <- "<none>"
-      stop(FutureError(sprintf("Cannot resolve %s (%s), because the connection to the worker is corrupt: %s", class(x)[1], label, attr(isValid, "reason", exact = TRUE)), future = future))
+      ex <- simpleError("Connection to the worker is corrupt")
+      msg <- post_mortem_cluster_failure(ex, when = "checking resolved from", node = node, future = future)
+      stop(FutureError(msg, future = future))
     }
 
     if (is.null(timeout)) {
@@ -389,9 +389,9 @@ receiveMessageFromWorker <- function(future, ...) {
     if (debug) mdebugf("- Validating connection of %s", class(future)[1])
     isValid <- isConnectionValid(con)
     if (!isValid) {
-      label <- future$label
-      if (is.null(label)) label <- "<none>"
-      stop(FutureError(sprintf("Cannot receive results for %s (%s), because the connection to the worker is corrupt: %s", class(future)[1], label, attr(isValid, "reason", exact = TRUE)), future = future))
+      ex <- simpleError("Connection to the worker is corrupt")
+      msg <- post_mortem_cluster_failure(ex, when = "receiving message from", node = node, future = future)
+      stop(FutureError(msg, future = future))
     }
   }
 
@@ -407,7 +407,7 @@ receiveMessageFromWorker <- function(future, ...) {
 
   if (inherits(ack, "error")) {
     if (debug) mdebugf("- parallel:::recvResult() produced an error: %s", conditionMessage(ack))
-    msg <- post_mortem_cluster_failure(ack, when = "receive results from", node = node, future = future)
+    msg <- post_mortem_cluster_failure(ack, when = "receive message results from", node = node, future = future)
     ex <- FutureError(msg, call = ack$call, future = future)
     future$result <- ex
     stop(ex)          
@@ -720,6 +720,7 @@ cluster_call <- function(cl, ..., when = "call function on", future) {
 }
 
 
+#' @importFrom parallelly isNodeAlive
 post_mortem_cluster_failure <- function(ex, when, node, future) {
   stop_if_not(inherits(ex, "error"))
   stop_if_not(length(when) == 1L, is.character(when))
@@ -763,9 +764,9 @@ post_mortem_cluster_failure <- function(ex, when, node, future) {
 
   ## (4) POST-MORTEM ANALYSIS:
   postmortem <- list()
-  ## (a) Did a localhost worker process terminate?
-  if (!is.null(host)) {
-    if (localhost && is.numeric(pid)) {
+  ## (a) Did the worker process terminate?
+  if (!is.null(host) && is.numeric(pid)) {
+    if (localhost) {
       pid_exists <- import_parallelly("pid_exists")
       alive <- pid_exists(pid)
       if (is.na(alive)) {
@@ -775,8 +776,18 @@ post_mortem_cluster_failure <- function(ex, when, node, future) {
       } else {
         msg2 <- "No process exists with this PID, i.e. the localhost worker is no longer alive"
       }
-      postmortem$alive <- msg2
+    } else {
+      ## Checking remote workers on hosts requires parallelly (>= 1.36.0)
+      alive <- isNodeAlive(node, timeout = getOption("future.alive.timeout", 30.0))
+      if (is.na(alive)) {
+        msg2 <- "Failed to determined whether the process with this PID exists or not on the remote host, i.e. cannot infer whether remote worker is alive or not"
+      } else if (alive) {
+        msg2 <- "A process with this PID exists on the remote host, which suggests that the remote worker is still alive"
+      } else {
+        msg2 <- "No process exists with this PID on the remote host, i.e. the remote worker is no longer alive"
+      }
     }
+    postmortem$alive <- msg2
   }
 
   ## (b) Did the worker use a connection that changed?
