@@ -157,37 +157,6 @@ plan <- local({
     FALSE
   }
 
-  warn_about_deprecated <- function(stack, strategy, fmtstr, ignore = NULL, defunct = NULL) {
-    for (kk in seq_along(stack)) {
-      if (evaluator_uses(stack[[kk]], strategy)) {
-        if (is.null(ignore)) ignore <- getOption("future.deprecated.ignore")
-        if (!is.element(strategy, ignore)) {
-          if (is.null(defunct)) defunct <- getOption("future.deprecated.defunct")
-          if (is.element(strategy, defunct)) {
-            msg <- sprintf(fmtstr, strategy, "defunct")
-            dfcn <- .Defunct
-          } else {
-            msg <- sprintf(fmtstr, strategy, "deprecated")
-            dfcn <- .Deprecated
-          }
-          dfcn(msg = msg, package = .packageName)
-        }
-      }
-    }
-  }
-
-  warn_about_multiprocess <- function(stack) {
-    warn_about_deprecated(stack, strategy = "multiprocess", fmtstr = sprintf("Strategy '%%s' is %%s in future (>= 1.32.0) [2023-03-06]. Instead, explicitly specify either 'multisession' (recommended) or 'multicore'."))
-  }
-
-  warn_about_remote <- function(stack) {
-    warn_about_deprecated(stack, strategy = "remote", fmtstr = "Strategy '%s' is %s in future (>= 1.30.0) [2022-12-15]. Instead, use plan(cluster, ..., persistent = TRUE).", ignore = "", defunct = "remote")
-  }
-
-  warn_about_transparent <- function(stack) {
-    warn_about_deprecated(stack, strategy = "transparent", fmtstr = "Strategy '%s' is %s in future (>= 1.28.0) [2022-09-02]. It was designed to simplify interactive troubleshooting, but is now superseded by plan(sequential, split = TRUE).", defunct = "transparent")
-  }
-
   warn_about_multicore <- local({
     .warn <- TRUE
 
@@ -294,9 +263,7 @@ plan <- local({
 
     assert_no_disallowed_strategies(newStack)
 
-    warn_about_multiprocess(newStack)
-    warn_about_remote(newStack)
-    warn_about_transparent(newStack)
+    ## Warn about 'multicore' on certain systems
     warn_about_multicore(newStack)
 
     stack <<- newStack
