@@ -1,13 +1,16 @@
 source("incl/start.R")
 options(future.debug = FALSE)
 
+## Don't poll too frequently in order for these tests to not fail
+options(future.wait.interval = 0.1)
+
 message("*** resolved() - assert non-blocking while launching lazy futures ...")
 
 for (cores in 1:availCores) {
   message(sprintf("Testing with %d cores ...", cores))
   options(mc.cores = cores)
 
-  strategies <- supportedStrategies(cores, excl = c("multiprocess"))
+  strategies <- supportedStrategies(cores)
   print(strategies)
   
   for (strategy in strategies) {
